package bmserv.resources;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;

import bmserv.Server;
import bmserv.TemplateEngine;
import bmserv.Utils;
import bmserv.model.Bookmark;
import bmserv.model.Tag;

@Path("/")
public class NavResource {
	@GET
	@Produces("text/html")
	public String getHome(@Context HttpServletRequest req) {
		HttpSession session = req.getSession();
		TemplateEngine.setSession(req.getSession());
		
		if(session.getAttribute("userid")!=null){
			String userid = (String) session.getAttribute("userid");
			System.out.println("Vous êtes identifié en tant que :"+userid);
			return TemplateEngine.buildFromFile("home.html");
		}else{
			return TemplateEngine.buildFromFile("login.html");
		}
	}
	
	@GET
	@Path("/{filename}")
	public String getFile(@PathParam("filename") String filename) {
		return TemplateEngine.getFile(filename);
	}
	
	@GET
	@Produces("text/html")
	@Path("/form/login")
	public String getLogin(@Context HttpServletRequest req) {
		TemplateEngine.setSession(req.getSession());
		return TemplateEngine.buildFromFile("login.html");
	}
	
	@GET
	@Produces("text/html")
	@Path("/form/user/add")
	public String getUserForm(@Context HttpServletRequest req) {
		TemplateEngine.setSession(req.getSession());
		return TemplateEngine.buildFromFile("adduser.html");
	}

	@GET
	@Produces("text/html")
	@Path("/form/tag/add")
	public String getTagForm(@Context HttpServletRequest req) {
		TemplateEngine.setSession(req.getSession());
		return TemplateEngine.buildFromFile("addtag.html");
	}

	@GET
	@Produces("text/html")
	@Path("/form/bookmark/add")
	public String getBookmarkForm(@Context HttpServletRequest req) {
		TemplateEngine.setSession(req.getSession());
		return TemplateEngine.buildFromFile("addbookmark.html");
	}
	@GET
	@Produces("text/html")
	@Path("/form/tagging/add")
	public String getTaggingForm(@Context HttpServletRequest req) {
		String pagebody = "";
		TemplateEngine.setSession(req.getSession());	
		try {
					
			// get resources info (path to addtagging.html, etc)
			Properties prop = new Properties();
			prop.load(new FileInputStream("./conf/server.properties"));
			String resdir = prop.getProperty("resources.repository.prefix");
			
			// addtagging template
			pagebody = Utils.readFileAsString(resdir+"addtagging.html");
			// replace {bmid_values} with values <option value="test1_id">test1_label</option>
			String bmid_values = new String();
			for(Bookmark bm : Server.bmh.getBookmarks()){
				//System.out.println("bmid: "+bm.getId()+"\tbmtitle: "+bm.getTitle());
				bmid_values=bmid_values.concat("<option value=\""+bm.getId()+"\">"+bm.getTitle()+"</option>");
			}		
			pagebody = pagebody.replace("{bmid_values}", bmid_values);
			// replace {tagid_value} with values <label for="male">Male</label>
			//<input type="checkbox" name="vehicle" value="Car" />
			String tagid_values = new String();
			String tagid_param_name = "tagid";
			for(Tag tag : Server.th.getTags()){
				tagid_values = tagid_values.concat("<dd><label for=\""+tag.getId()+"\">"+tag.getLabel()+
						"</label><input type=\"checkbox\" id=\""+tag.getId()+"\" name=\""+tagid_param_name+"\" value=\""+tag.getId()+"\"/></dd>");
			}
			System.out.println("[buildAddTaggingFormFromFile]tagid_values"+tagid_values);
			pagebody = pagebody.replace("{tagid_values}", tagid_values);	
			
		} catch (FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return TemplateEngine.build(pagebody);
	}	
}
